@@ -32,14 +32,6 @@
 
 class Calc : public Lum::Component
 {
-public:
-  class Prefs : public Lum::Component::Prefs
-  {
-  public:
-    Prefs();
-    void Initialize();
-  };
-
 private:
   Lum::Model::ActionRef    calculate;
   Lum::Model::ListTableRef history;
