@@ -36,8 +36,6 @@
 #include "NumberInput.h"
 #include "Util.h"
 
-static Plot::Prefs* prefs=new Plot::Prefs();
-
 class FunctionDialog : public Lum::Dialog
 {
 private:
@@ -96,7 +94,6 @@ void FunctionDialog::PreInit()
   functionControl->SetFlex(true,false);
   functionControl->SetRequestsKeyboard(false);
   functionControl->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
-  functionControl->RequestFocus();
   functionControl->SetModel(function);
   label->AddLabel(L"Function:",functionControl);
 
@@ -113,14 +110,12 @@ void FunctionDialog::PreInit()
   buttonRow->SetFlex(true,false);
 
   button=new Lum::Button(_ld(dlgButtonOk));
-  button->RequestFocus();
   button->SetFlex(true,true);
   button->SetType(Lum::Button::typeCommit);
   button->SetModel(okAction);
   buttonRow->Add(button);
 
   button=new Lum::Button(_ld(dlgButtonCancel));
-  button->RequestFocus();
   button->SetFlex(true,true);
   button->SetType(Lum::Button::typeCancel);
   button->SetModel(GetClosedAction());
@@ -247,19 +242,16 @@ void FunctionsDialog::PreInit()
   vert->SetFlex(false,true);
 
   button=new Lum::Button(L"_Add");
-  button->RequestFocus();
   button->SetFlex(true,false);
   button->SetModel(addAction);
   vert->Add(button);
 
   button=new Lum::Button(L"_Modify");
-  button->RequestFocus();
   button->SetFlex(true,false);
   button->SetModel(updateAction);
   vert->Add(button);
 
   button=new Lum::Button(L"_Remove");
-  button->RequestFocus();
   button->SetFlex(true,false);
   button->SetModel(removeAction);
   vert->Add(button);
@@ -273,7 +265,6 @@ void FunctionsDialog::PreInit()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->RequestFocus();
   table->SetMinWidth(Lum::Base::Size::stdCharWidth,40);
   table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,6);
   table->SetShowHeader(true);
@@ -291,7 +282,6 @@ void FunctionsDialog::PreInit()
   buttonRow->SetFlex(true,false);
 
   button=new Lum::Button(_ld(dlgButtonClose));
-  button->RequestFocus();
   button->SetFlex(true,true);
   button->SetType(Lum::Button::typeCommit);
   button->SetModel(GetClosedAction());
@@ -475,7 +465,6 @@ public:
     horiz->Add(new Lum::HSpace(true));
 
     string=new Lum::String();
-    string->RequestFocus();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
@@ -495,7 +484,6 @@ public:
     horiz->SetFlex(true,false);
 
     string=new Lum::String();
-    string->RequestFocus();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
@@ -506,7 +494,6 @@ public:
     horiz->Add(new Lum::HSpace());
 
     string=new Lum::String();
-    string->RequestFocus();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
@@ -526,7 +513,6 @@ public:
     horiz->Add(new Lum::HSpace(true));
 
     string=new Lum::String();
-    string->RequestFocus();
     string->SetRequestsKeyboard(false);
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
     string->SetAlignment(Lum::String::right);
@@ -548,14 +534,12 @@ public:
     row->SetFlex(true,false);
 
     button=new Lum::Button(_ld(dlgButtonOk));
-    button->RequestFocus();
     button->SetFlex(true,true);
     button->SetType(Lum::Button::typeCommit);
     button->SetModel(okAction);
     row->Add(button);
 
     button=new Lum::Button(_ld(dlgButtonCancel));
-    button->RequestFocus();
     button->SetFlex(true,true);
     button->SetType(Lum::Button::typeCancel);
     button->SetModel(GetClosedAction());
@@ -598,27 +582,12 @@ public:
   }
 };
 
-Plot::Prefs::Prefs()
- : Lum::Component::Prefs(L"Plot")
-{
-  // no code
-}
-
-void Plot::Prefs::Initialize()
-{
-  Lum::Component::Prefs::Initialize();
-
-  frame=new Lum::OS::EmptyFrame();
-}
-
 Plot::Plot()
 : history(new Lum::Model::ListTable(1)),
   editFunctions(new Lum::Model::Action()),
   autosize(new Lum::Model::Action()),
   region(new Lum::Model::Action())
  {
-  SetPrefs(::prefs);
-
   plotVar=parser.AddVariable("x",0.0);
 
   functions=new Functions(plotVar);
@@ -705,21 +674,18 @@ void Plot::CalcSize()
 
   button=new Lum::Button();
   button->SetFlex(true,false);
-  button->RequestFocus();
   button->SetModel(editFunctions);
   button->SetText(L"_f(x)");
   row->Add(button);
 
   button=new Lum::Button();
   button->SetFlex(true,false);
-  button->RequestFocus();
   button->SetModel(autosize);
   button->SetText(L"_Autosize");
   row->Add(button);
 
   button=new Lum::Button();
   button->SetFlex(true,false);
-  button->RequestFocus();
   button->SetModel(region);
   button->SetText(L"_Region");
   row->Add(button);
