@@ -23,8 +23,6 @@
 
 #include "Util.h"
 
-static Plotter::Prefs *prefs=new Plotter::Prefs();
-
 Functions::Function::Function(const std::wstring& function, Parser::Expression *expression)
  : function(function),
    expression(expression)
@@ -140,15 +138,6 @@ double Functions::GetRight() const
   return right;
 }
 
-
-void Plotter::Prefs::Initialize()
-{
-  Lum::Object::Prefs::Initialize();
-
-  background=Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex);
-  frame=Lum::OS::display->GetFrame(Lum::OS::Display::listboxFrameIndex);
-}
-
 double exponent(double x)
 {
   if (x>=0) {
@@ -166,7 +155,7 @@ Plotter::Plotter()
   right(0.0),
   areaSelection(false)
 {
-  SetPrefs(::prefs);
+  SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
 }
 
 Plotter::~Plotter()
@@ -217,7 +206,7 @@ void Plotter::Draw(int x, int y, size_t w, size_t h)
 {
   Lum::Control::Draw(x,y,w,h);
 
-  if (!Intersect(x,y,w,h)) {
+  if (!OIntersect(x,y,w,h)) {
     return;
   }
 
