@@ -22,24 +22,9 @@
 #include <Lum/Panel.h>
 #include <Lum/Text.h>
 
-static UnitConversion::Prefs* prefs=new UnitConversion::Prefs();
-
-UnitConversion::Prefs::Prefs()
- : Lum::Component::Prefs(L"UnitConversion")
-{
-  // no code
-}
-
-void UnitConversion::Prefs::Initialize()
-{
-  Lum::Component::Prefs::Initialize();
-
-  frame=new Lum::OS::EmptyFrame();
-}
-
 UnitConversion::UnitConversion()
 {
-  SetPrefs(::prefs);
+  // no code
 }
 
 void UnitConversion::CalcSize()
