@@ -24,16 +24,9 @@
 
 class UnitConversion : public Lum::Component
 {
-public:
-  class Prefs : public Lum::Component::Prefs
-  {
-  public:
-    Prefs();
-    void Initialize();
-  };
-
 public:
   UnitConversion();
+
   void CalcSize();
 };
 
